==> mfc-vms-meta-model-0.1.0-sources.jar: com/valor/mfc/vms/meta/model/database/dto/PersonDto.java <==
package com.valor.mfc.vms.meta.model.database.dto;

import com.google.common.collect.Sets;

import com.valor.mfc.vms.meta.model.database.ddo.person.AbstractPersonFilmography;
import com.valor.mfc.vms.meta.model.database.ddo.person.AbstractPersonLocale;
import com.valor.mfc.vms.meta.model.database.ddo.person.Person;
import com.valor.mfc.vms.meta.model.database.ddo.person.PersonAward;
import com.valor.mfc.vms.meta.model.database.ddo.person.PersonKnowFor;
import com.valor.mfc.vms.meta.model.database.ddo.person.PersonLocale;

import java.util.Objects;
import java.util.Set;

/**
 * Created by Frank.Huang on 2016/5/7.
 */
public class PersonDto {
    private Person person;
    private PersonLocale locale;
    private AbstractPersonLocale mlLocale;
    private Set<PersonKnowFor> knowFors          = Sets.newHashSet();
    private Set<PersonAward> awards              = Sets.newHashSet();
    private Set<AbstractPersonFilmography> filmographies = Sets.newHashSet();


    public Person getPerson() {
        return person;
    }

    public void setPerson(Person person) {
        this.person = person;
    }

    public PersonLocale getLocale() {
        return locale;
    }

    public void setLocale(PersonLocale locale) {
        this.locale = locale;
    }

    public Set<PersonKnowFor> getKnowFors() {
        return knowFors;
    }

    public void setKnowFors(Set<PersonKnowFor> knowFors) {
        this.knowFors = knowFors;
    }

    public boolean isValid(){
        if (Objects.isNull(person)){
            return false;
        }

        return true;
    }

    public Set<PersonAward> getAwards() {
        return awards;
    }

    public void setAwards(Set<PersonAward> awards) {
        this.awards = awards;
    }

    public Set<AbstractPersonFilmography> getFilmographies() {
        return filmographies;
    }

    public void setFilmographies(Set<AbstractPersonFilmography> filmographies) {
        this.filmographies = filmographies;
    }

    public AbstractPersonLocale getMlLocale() {
        return mlLocale;
    }

    public void setMlLocale(AbstractPersonLocale mlLocale) {
        this.mlLocale = mlLocale;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        PersonDto that = (PersonDto) o;

        return com.google.common.base.Objects.equal(this.person, that.person);
    }

    @Override
    public int hashCode() {
        return com.google.common.base.Objects.hashCode(person);
    }
}

==> mfc-vms-meta-model-0.1.5-sources.jar: com/valor/mfc/vms/meta/model/database/dto/PersonDto.java <==
package com.valor.mfc.vms.meta.model.database.dto;

import com.google.common.collect.Sets;
import com.valor.mfc.vms.meta.model.database.ddo.person.*;

import java.util.Objects;
import java.util.Set;

/**
 * Created by Frank.Huang on 2016/5/7.
 */
public class PersonDto {
    private Person person;
    private PersonLocale locale;
//    private AbstractPersonLocale mlLocale;
    private Set<AbstractPersonLocale> mlLocales;
    private Set<PersonKnowFor> knowFors          = Sets.newHashSet();
    private Set<PersonAward> awards              = Sets.newHashSet();
    private Set<AbstractPersonFilmography> filmographies = Sets.newHashSet();
    private PersonStarMeter personStarMeter;
    private Set<PersonTag> personTags              = Sets.newHashSet();

    public Person getPerson() {
        return person;
    }

    public void setPerson(Person person) {
        this.person = person;
    }

    public PersonLocale getLocale() {
        return locale;
    }

    public void setLocale(PersonLocale locale) {
        this.locale = locale;
    }

    public Set<PersonKnowFor> getKnowFors() {
        return knowFors;
    }

    public void setKnowFors(Set<PersonKnowFor> knowFors) {
        this.knowFors = knowFors;
    }


    public Set<PersonTag> getPersonTags() {
        return personTags;
    }

    public void setPersonTags(Set<PersonTag> personTags) {
        this.personTags = personTags;
    }

    public boolean isValid(){
        if (Objects.isNull(person)){
            return false;
        }

        return true;
    }

    public Set<PersonAward> getAwards() {
        return awards;
    }

    public void setAwards(Set<PersonAward> awards) {
        this.awards = awards;
    }

    public Set<AbstractPersonFilmography> getFilmographies() {
        return filmographies;
    }

    public void setFilmographies(Set<AbstractPersonFilmography> filmographies) {
        this.filmographies = filmographies;
    }

    public Set<AbstractPersonLocale> getMlLocales() {
        return mlLocales;
    }

    public void setMlLocales(Set<AbstractPersonLocale> mlLocales) {
        this.mlLocales = mlLocales;
    }

    public PersonStarMeter getPersonStarMeter() {
        return personStarMeter;
    }

    public void setPersonStarMeter(PersonStarMeter personStarMeter) {
        this.personStarMeter = personStarMeter;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        PersonDto that = (PersonDto) o;

        return com.google.common.base.Objects.equal(this.person, that.person);
    }

    @Override
    public int hashCode() {
        return com.google.common.base.Objects.hashCode(person);
    }
}
